@@ -1,9 +1,10 @@
-AGENT_ACTIVE_MODE = 'STOOBLY_AGENT_ACTIVE_MODE'
 AGENT_CONFIG_PATH = 'STOOBLY_AGENT_CONFIG_PATH'
 AGENT_ENABLED = 'STOOBLY_AGENT_ENABLED'
 AGENT_SELF_INTERCEPT_ENABLED = 'STOOBLY_AGENT_SELF_INTERCEPT_ENABLED'
+AGENT_HEADLESS = 'STOOBLY_AGENT_HEADLESS'
 AGENT_INCLUDE_PATTERNS = 'STOOBLY_AGENT_INCLUDE_PATTERNS'
-AGENT_IS_HEADLESS = 'STOOBLY_AGENT_IS_HEADLESS'
+AGENT_INTERCEPT_ACTIVE = 'STOOBLY_AGENT_INTERCEPT_ACTIVE'
+AGENT_INTERCEPT_MODE = 'STOOBLY_AGENT_INTERCEPT_MODE'
 AGENT_EXCLUDE_PATTERNS = 'STOOBLY_AGENT_EXCLUDE_PATTERNS'
 AGENT_LIFECYCLE_HOOKS_PATH = 'STOOBLY_AGENT_LIFECYCLE_HOOKS_PATH'
 AGENT_POLICY = 'STOOBLY_AGENT_POLICY'
@@ -18,7 +19,7 @@ AGENT_RESPONSE_FIXTURES_PATH = 'STOOBLY_AGENT_RESPONSE_FIXTURES_PATH'
 AGENT_SERVICE_URL = 'STOOBLY_AGENT_SERVICE_URL'
 AGENT_SCENARIO_KEY = 'STOOBLY_AGENT_SCENARIO_KEY'
 AGENT_SIMULATE_LATENCY = 'STOOBLY_AGENT_SIMULATE_LATENCY'
-AGENT_URL = 'STOOBLY_AGENT_URL'
+AGENT_UI_URL = 'STOOBLY_AGENT_UI_URL'
 API_URL = 'STOOBLY_API_URL'
 API_KEY = 'STOOBLY_API_KEY'
 ENV = 'STOOBLY_AGENT_ENV'
